@@ -21,7 +21,7 @@ module T::Types
 
     # overrides Base
     def valid?(obj)
-      obj.is_a?(Module) && (obj.is_a?(@type.singleton_class) || false)
+      obj.is_a?(@type.singleton_class)
     end
 
     # overrides Base
@@ -31,7 +31,7 @@ module T::Types
         @type.is_a?(other.type.singleton_class)
       when Simple
         @type.is_a?(other.raw_type)
-      when TypedClass
+      when TypedClass, TypedModule
         @type.is_a?(other.underlying_class)
       else
         false
